==> deepin-update-ui_1.0.6.tar.xz: BUILD/src/dcc-update-plugin/translations/update_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Última verificação:</translation>
    </message>
</context>
<context>
    <name>NoActive</name>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Seu sistema não está ativado e não conseguiu se conectar aos serviços de atualizações.</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Se você sair do programa beta, não receberá mais atualizações beta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Save the display settings?</source>
        <translation type="unfinished">Salvar as configurações de exibição?</translation>
    </message>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation type="unfinished">As configurações serão revertidas em %1s.</translation>
    </message>
    <message>
        <source>Settings will be reverted in %1s.</source>
        <translation>As configurações serão revertidas em %1s.</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation type="unfinished">Reverter</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Salvar</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Ver detalhes</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Atualizações:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Data de lançamento:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Recolher</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>NENHUM</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>BAIXO</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MÉDIO</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ALTO</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>CRÍTICO</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>risco crítico</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>risco elevado</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>risco médio</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>risco baixo</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconhecido</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Esta atualização corrige</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>vulnerabilidades</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>vulnerabilidade</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 de %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>para maiores detalhes, visite:</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Verificando atualizações, aguarde…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Seu sistema está atualizado</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>O download das atualizações falhou. Primeiro, libere %1 de espaço em disco.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Erro de Dependência! Falha ao Detectar Atualizações</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Verifique sua conexão e tente novamente.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>O download das atualizações falhou. Verifique sua conexão e tente novamente.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossível executar o backup do sistema. Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Espaço insuficiente em disco</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Erro do DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Arquivo ausente</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>A conexão do serviço está anormal, verifique a conexão e tente novamente</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>A configuração da fonte do repositório não é válida, verifique e tente novamente.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Verificar novamente</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Troca inteligente de espelho</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Tipo de atualização</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Atualização de função</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Oferece uma atualização cumulativa incluindo novos recursos, atualizações de qualidade e atualizações de segurança</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Atualizações de Segurança</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Fornece atualizações de segurança</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Atualizações de terceiros</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Fornece atualizações para fontes de repositório adicionais</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Limite de velocidade</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Definição de limites</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Download automático</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Habilitar &quot;Download automático de atualizações&quot; fará o download automático das atualizações quando conectado à Internet</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Download quando inativo</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Iniciar em</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Termina em</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Configurações avançadas</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Notificação de Atualizações</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Limpar cache de pacotes</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Histórico de Atualizações</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Participar do canal de testes interno</translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates</source>
        <translation>Participe do canal de testes internos para receber as atualizações mais recentes</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Clique aqui para completar a aplicação</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Atualizações do Sistema</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Correção de alguns bugs conhecidos e vulnerabilidades de segurança</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Atualizações de Segurança</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Repositórios de terceiros</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Atualizações do Sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Atualização do sistema e melhorias</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Configurações de atualização</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Download concluído</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Instalar atualizações</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Tamanho da atualização: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Download falhou</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Baixando atualizações...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Configurar as atualizações de segurança, download automático de atualizações e notificação de atualizações</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Reiniciar agora</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Instalando atualizações...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Tentar Novamente</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Continuar a atualização</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Atualizações disponíveis</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Falha na Instalação</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Para garantir o funcionamento adequado do seu sistema e aplicativos, reinicie o computador após a atualização</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Fazendo backup, aguarde...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Fazendo backup, aguarde...</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>O backup falhou</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Atualização instalada com sucesso</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Faça backup novamente</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dcc-update-plugin/translations/update_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Última verificação:</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Se você sair do programa beta, não receberá mais atualizações beta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
</context>
<context>
    <name>UpdateDisable</name>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>As atualizações do sistema estão desativadas. Por favor, entre em contato com o administrador para obter ajuda.</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Seu sistema não está ativado e não conseguiu conectar aos serviços de atualização.</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Histórico de Atualizações</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Nenhum histórico de atualizações</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Atualizações do Sistema</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Atualizações de segurança</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Inclui novos recursos, atualizações de qualidade e de segurança em um pacote cumulativo.</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Fornece atualizações de segurança</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Data de Instalação</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Ver detalhes</translation>
    </message>
    <message>
        <source>Updates:</source>
        <translation>Atualizações:</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Data de lançamento:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Recolher</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>NENHUM</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>BAIXO</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MÉDIO</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ALTO</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>CRÍTICO</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>risco crítico</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>risco elevado</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>risco médio</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>risco baixo</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>desconhecido</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Esta atualização corrige</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>vulnerabilidades</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>vulnerabilidade</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 de %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>para maiores detalhes, visite:</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Verificando atualizações, aguarde…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Seu sistema está atualizado</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erro desconhecido</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>O download das atualizações falhou. Primeiro, libere %1 de espaço em disco.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Erro de Dependência! Falha ao Detectar Atualizações</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Verifique sua conexão e tente novamente.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>O download das atualizações falhou. Verifique sua conexão e tente novamente.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossível executar o backup do sistema. Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Espaço insuficiente em disco</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Erro do DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Arquivo ausente</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>A conexão do serviço está anormal, verifique a conexão e tente novamente</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>A configuração da fonte do repositório não é válida, verifique e tente novamente.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Verificar novamente</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Política de Privacidade</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Para usar este software, você deve aceitar o %1 que acompanha as atualizações.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Ative os interruptores em Conteúdo da Atualização para obter uma melhor experiência</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Troca inteligente de espelho</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Tipo de atualização</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Atualização de função</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Oferece uma atualização cumulativa incluindo novos recursos, atualizações de qualidade e atualizações de segurança</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Atualizações de Segurança</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Fornece atualizações de segurança</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Atualizações de terceiros</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Fornece atualizações para fontes de repositório adicionais</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Limite de velocidade</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Definição de limites</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Download automático</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Habilitar &quot;Download automático de atualizações&quot; fará o download automático das atualizações quando conectado à Internet</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Download quando inativo</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Iniciar em</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Termina em</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Configurações avançadas</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Notificação de Atualizações</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Limpar cache de pacotes</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Histórico de Atualizações</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Participar do canal de testes interno</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Clique aqui para completar a aplicação</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandir</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Atualizações do Sistema</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Correção de alguns bugs conhecidos e vulnerabilidades de segurança</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Atualizações de Segurança</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Repositórios de terceiros</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Atualizações do Sistema</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Atualização do sistema e melhorias</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Configurações de atualização</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Download concluído</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Instalar atualizações</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Tamanho da atualização: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Download falhou</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Baixando atualizações...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Configurar as atualizações de segurança, download automático de atualizações e notificação de atualizações</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Reiniciar agora</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Instalando atualizações...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Tentar Novamente</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Continuar a atualização</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Atualizações disponíveis</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Falha na Instalação</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Para garantir o funcionamento adequado do seu sistema e aplicativos, reinicie o computador após a atualização</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Fazendo backup, aguarde...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Fazendo backup, aguarde...</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>O backup falhou</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Atualização instalada com sucesso</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Se você continuar com as atualizações, não poderá reverter o sistema para uma versão anterior.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Tentar novamente</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Prosseguir com a atualização</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>A capacidade da bateria está abaixo de 60%. Para atualizar sem riscos de problemas, conecte o carregador.</translation>
    </message>
</context>
</TS>
